from setuptools import setup, find_packages

setup(
    name='AAmyMilePackage',
    version='0.3',
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description='A test python package',
	url='https://github.com/Aanu-A/AAmyMilePackaging.git',
    author='A Abayomi',
    author_email='aanuabayom@gmail.com'
)
